#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
%define         X_display         ":98"
Name:           python-QDarkStyle%{psuffix}
Version:        3.2.1
Release:        1.5
Summary:        A dark stylesheet for Python and Qt applications
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ColinDuquesnoy/QDarkStyleSheet
Source:         https://github.com/ColinDuquesnoy/QDarkStyleSheet/archive/v%{version}.tar.gz#/QDarkStyle-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-QtPy >= 2
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module QDarkStyle = %{version}}
BuildRequires:  %{python_module QtPy >= 2}
BuildRequires:  %{python_module qt5-devel}
# pyside2 is for primary python3 flavor only
BuildRequires:  python3-pyside2
BuildRequires:  xvfb-run
%endif
%python_subpackages

%description
QDarkStyle is a dark stylesheet for Python and Qt applications.

%prep
%autosetup -p1 -n QDarkStyleSheet-%{version}
sed -i '1{\,^#!%{_bindir}/env python,d}' qdarkstyle/*.py qdarkstyle/*/*.py

%build
%if !%{with test}
%python_build
%endif

%install
%if !%{with test}
%python_install
%python_clone -a %{buildroot}%{_bindir}/qdarkstyle
%python_clone -a %{buildroot}%{_bindir}/qdarkstyle.example
%python_clone -a %{buildroot}%{_bindir}/qdarkstyle.utils
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
export LANG=C.UTF-8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} xvfb-run $python -B -m qdarkstyle.example --qt_from=pyqt5 --test
# pyside2 is for primary python3 flavor only
PYTHONPATH=%{buildroot}%{python3_sitelib} xvfb-run python3 -B -m qdarkstyle.example --qt_from=pyside2 --test
# no qtsass compiler (extras_require 'develop')
#%%pytest
%endif

%post
%python_install_alternative qdarkstyle qdarkstyle.example qdarkstyle.utils

%postun
%python_uninstall_alternative qdarkstyle

%if !%{with test}
%files %{python_files}
%doc AUTHORS.rst CHANGES.rst README.rst
%license LICENSE.rst
%python_alternative %{_bindir}/qdarkstyle
%python_alternative %{_bindir}/qdarkstyle.example
%python_alternative %{_bindir}/qdarkstyle.utils
%{python_sitelib}/qdarkstyle
%{python_sitelib}/QDarkStyle-%{version}*-info
%endif

%changelog
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.2.1
  * Add COLOR_DISABLED to vars #337
  * Enhance contributing guide
- Release 3.2:
  * Improve C++ usage description #329
  * Add Qt6 support, fixes entries and docs
  * Fix warnings calls #325
  * Fix hidden background Qtoolbox MR #324
  * Enhance contrast ligh theme MR #335
  * Drop Python 2 support #327
  * Add constant to disable color of widgets
  * Fixes small typos and shebang cleanup
- Release 3.1:
  * Fixes generating resources
  * Correct spelling mistakes
  * Refactoring functions from qdarkstyle.utils
  * Include prefix of palette.ID for qrc, qss, _rc files, keep
    working on C++ #273
  * Fix global variables issue #298
  * Include data files when installing package #299
- Release 3.0.3:
  * Temporary fix for expanded combo box in Qt 5.15, fixes #282,
    [#285], MR #288
  * Fix generating assets in Posix
  * Fix tristate value for checkbox #275
  * Minor fixes and improvements
- Drop QDarkStyle-issue275-pyside2.patch
* Wed Aug 16 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Apr  8 2021 Ben Greiner <code@bnavigator.de>
- Update to version 3.0.2
  * Enable the use of setTabColor and add example, fixes #212
  * Update description to inform about Python 2 and Qt4 unsupported
    versions
  * Add missing examples #251
  * Enhancement of state of active/non-active items in views #209
  * Update manifest to include UI files
  * New structure to create different palettes #268, #164
  * New light palette #240, #268
  * Improved dark palette #252, #266, #264, #265, #248
  * Improved tool buttons #260
  * Improved tabs #270, #271, #267
  * Improved combo boxes #263
  * Improved close/float sizes os-dependent #267
  * Fix checkbox problems #200, #259, #239
  * Fix indicators' colors in menus and tables #242
  * Fix dock widget tab hover #243
  * Workaround for menus with indicators and icons #214
  * Update to be compatible with Qt 5.[12,13,14,15]
- add QDarkStyle-issue275-pyside2.patch
  gh#ColinDuquesnoy/QDarkStyleSheet#275
* Wed Dec 23 2020 Benjamin Greiner <code@bnavigator.de>
- Support for multiple python3 flavors
  * Put standalone command under update-alternatives control
  * test pyside2 only with primary python3 flavor
  * gh#openSUSE/python-rpm-macros#66
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Add _multibuild to run the test in a flavor and use xvfb-run
  instead of calling the Xvfb server directly and depending on the
  xorg-x11-server-Xvfb package which is not available in SLE/Leap.
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 2.8.1:
  * Fix rst file formats and links #229
  * Add .gitattributes for generated and documentation files
  * Add more complete tox and Travis envs with many checks
  * Fix removing message format argument
  * Fix QGroupBox small indicator size #218
  * Fix QGroupBox incorrect indicator icon when unfocused #219
  * Fix QDateTimeEdit incorrect drop-down arrow icon #220
  * Fix documentation
* Tue Jan 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the tarball fetching
* Sat Jan 25 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- disable python2 as build dependency pyside is only available on python3
- update to version 2.8:
  - Fix tooltip giant rectangle #174
  - Fix QTextEdit wihout borders inside frame #188
  - Fix PyQt5 issuies on dropbown #191
  - Fix combo box with icons #169
  - Fix QToolbBar vertical handle #210
  - Fix pane tab labelcropped on activation #199
  - Enhance vertical/horiontal lines #184
  - Enhance tool button size and spacing #181, #183, #202
  - Enhance buttons and inputs with focus, blue border #194, #211
  - Enhance QSplitter #207
  - Removed QStatusBar vertical lines #205
- update to version 2.7:
  - Remove utils from import in qdarkstyle, #170
  - Fix border colors in tool button #176
  - Fix scroll area and stacked with 2px padding, #159
  - Fix backgroung submenu color, #179
  - Fix extra border aside header's arrow indicator, #180
  - Fix menu right arrrow indicator
  - Fix slide bars colors, #150
  - Fix QLabels problems, #163, #139
  - Fix problems with example settings using PySide2 and --no\_dark #167
  - Provide SVG files for all images, standard names and sizes, fix images, #149
  - Improve images and add high resolution images, #140
  - Improve docs
  - Add check to scripts for generating images, #137
  - Fix tox and travis scripts #76
  - Provide docs in RTD, part of #160
  - Add helpdev depedency for reports and checks, #147
  - Update authors and maintainers
* Thu May 23 2019 pgajdos@suse.com
- version update to 2.6.8
  - Fix double border in QtabWidget for pyqt5
  - Fix widgets border in QTabWidget as QLabel  #141, #123, #126
  - Fix QTab scroller buttons background #136
  - Update color from images, fix #127
  - Add retina resolution @2x, fix #140
  - Intermediate version before merge PR #142 adding scripts
  - Fix combobox indicator and padding #132
  - Fix PyQtGraph plot axes covered by padding #134
  - Update authors
  - Fix tabbed bordeless frames and add more examples, #123, #126
  - Add feedback to pressed buttons, #133
  - Change future warning to pending deprecation for developers, #125 in v2.x
  - Fix hover in qtabwidget, #128
* Tue Jan 29 2019 Antonio Larrosa <alarrosa@suse.com>
- Use version from git and enable tests (just for python3 since
  pyside2 is not available for python2 and just qt5 bindings
  because qt4 doesn't support painting offscreen and thus needs
  an X server).
* Sun Jan 27 2019 alarrosa@suse.com
- Initial release of python-QDarkStyle 2.6.5
